Ballast Capacity Series
-----------------------

Aggregated from :ref:`Ballast Capacity Port Calls`

.. note::
    available on platforms : Platform.Liquids, Platform.LNG, Platform.LPG, Platform.Dry

.. autoclass:: kpler.sdk.resources.ballast_capacity_series.BallastCapacitySeries
    :members:

.. autoclass:: kpler.sdk.BallastCapacitySeriesMetric
    :members:

.. autoclass:: kpler.sdk.BallastCapacitySeriesPeriod
    :members:

.. autoclass:: kpler.sdk.BallastCapacitySeriesSplit
    :members:

.. autoclass:: kpler.sdk.BallastCapacitySeriesUnit
    :members:

.. autoclass:: kpler.sdk.VesselTypesCPP
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesOil
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLNG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLPG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesDry
    :members:
    :noindex:
